/*
 * Sonar, entreprise quality control tool.
 * Copyright (C) 2007-2008 Hortis-GRC SA
 * mailto:be_agile HAT hortis DOT ch
 *
 * Sonar is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * Sonar is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with {library}; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02
 */
package ch.hortis.sonar.web.utils;

import java.io.IOException;
import java.io.InputStream;
import java.util.Properties;

public final class Version {

  protected static String version;

  private Version() {
  }

  public static String getVersion() throws IOException {
    return getVersion("/META-INF/maven/org.codehaus.sonar/sonar-core/pom.properties");
  }

  protected static String getVersion(String pomFilename) throws IOException {
    if (version == null) {
      InputStream pomFileStream = Version.class.getResourceAsStream(pomFilename);
      try {
        version = readVersion(pomFileStream);
      } finally {
        if (pomFileStream != null) {
          pomFileStream.close();
        }
      }
    }
    return version;
  }

  protected static String readVersion(InputStream pomFileStream) throws IOException {
    String result = "";
    if (pomFileStream!=null) {
      Properties pomProp = new Properties();
      pomProp.load(pomFileStream);
      result = pomProp.getProperty("version");
      if (result == null) {
        result = "";
      }
    }

    return result;
  }
}